Introduction
============

SOAP webservices for Products.PloneMeeting.

Version 2.x is for Products.PloneMeeting 4.1 and version 3.x is for Products.PloneMeeting 4.2.

WS4PM files
===========

These files are generated using a static WSDL file.

Adaptations must be done in file soap/ws4pmwsdl.pt, then the static WSDL file dumpedWSDL.txt
is generated by calling `http://portal_url/@@ws4pm.wsdl?dump_wsdl:boolean=True`.

After that, call ZSI wsdl2py script with following syntax : /path_to_ZSI_package/bin/wsdl2py dumpedWSDL.txt -o . -b
